@@ -17,6 +17,8 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/config"
 	"gitlab.com/gitlab-org/cli/pkg/glinstance"
 	"gitlab.com/gitlab-org/cli/pkg/oauth2"
+
+	oauthz "golang.org/x/oauth2"
 )
 
 // AuthType represents an authentication type within GitLab.
@@ -90,14 +92,6 @@ func RefreshClient() {
 	}
 }
 
-// GetClient returns the global Client instance.
-func GetClient() *Client {
-	return apiClient
-}
-
-// HTTPClient returns the httpClient instance used to initialise the gitlab api client
-func HTTPClient() *http.Client { return apiClient.HTTPClient() }
-
 func (c *Client) HTTPClient() *http.Client {
 	if c.httpClientOverride != nil {
 		return c.httpClientOverride
@@ -108,21 +102,14 @@ func (c *Client) HTTPClient() *http.Client {
 	return &http.Client{}
 }
 
-// OverrideHTTPClient overrides the default http client
-func OverrideHTTPClient(client *http.Client) { apiClient.OverrideHTTPClient(client) }
-
 func (c *Client) OverrideHTTPClient(client *http.Client) {
 	c.httpClientOverride = client
 }
 
-// Token returns the authentication token
-func Token() string { return apiClient.Token() }
-
 func (c *Client) Token() string {
 	return c.token
 }
 
-func SetProtocol(protocol string) { apiClient.SetProtocol(protocol) }
 func (c *Client) SetProtocol(protocol string) {
 	c.Protocol = protocol
 }
@@ -159,8 +146,7 @@ func NewClient(host, token string, allowInsecure bool, isGraphQL bool, isOAuth2
 	if apiClient.httpClientOverride == nil {
 		apiClient.httpClient = &http.Client{
 			Transport: &http.Transport{
-				DisableKeepAlives: DisableHTTPKeepAlives,
-				Proxy:             http.ProxyFromEnvironment,
+				Proxy: http.ProxyFromEnvironment,
 				DialContext: (&net.Dialer{
 					Timeout:   5 * time.Second,
 					KeepAlive: 5 * time.Second,
@@ -202,8 +188,7 @@ func NewClientWithCustomCA(host, token, caFile string, isGraphQL bool, isOAuth2
 
 		apiClient.httpClient = &http.Client{
 			Transport: &http.Transport{
-				DisableKeepAlives: DisableHTTPKeepAlives,
-				Proxy:             http.ProxyFromEnvironment,
+				Proxy: http.ProxyFromEnvironment,
 				DialContext: (&net.Dialer{
 					Timeout:   30 * time.Second,
 					KeepAlive: 30 * time.Second,
@@ -254,8 +239,7 @@ func NewClientWithCustomCAClientCert(host, token, caFile string, certFile string
 
 		apiClient.httpClient = &http.Client{
 			Transport: &http.Transport{
-				DisableKeepAlives: DisableHTTPKeepAlives,
-				Proxy:             http.ProxyFromEnvironment,
+				Proxy: http.ProxyFromEnvironment,
 				DialContext: (&net.Dialer{
 					Timeout:   30 * time.Second,
 					KeepAlive: 30 * time.Second,
@@ -278,7 +262,7 @@ func NewClientWithCustomCAClientCert(host, token, caFile string, certFile string
 }
 
 // NewClientWithCfg initializes the global api with the config data
-func NewClientWithCfg(repoHost string, cfg config.Config, isGraphQL bool) (client *Client, err error) {
+func NewClientWithCfg(repoHost string, cfg config.Config, isGraphQL bool) (*Client, error) {
 	if repoHost == "" {
 		repoHost = glinstance.OverridableDefault()
 	}
@@ -290,14 +274,14 @@ func NewClientWithCfg(repoHost string, cfg config.Config, isGraphQL bool) (clien
 
 	apiProtocol, _ := cfg.Get(repoHost, "api_protocol")
 	if apiProtocol != "" {
-		SetProtocol(apiProtocol)
+		apiClient.SetProtocol(apiProtocol) // TODO remove this together with global apiClient.
 	}
 
 	isOAuth2Cfg, _ := cfg.Get(repoHost, "is_oauth2")
 	isOAuth2 := false
 	if isOAuth2Cfg == "true" {
 		isOAuth2 = true
-		err = oauth2.RefreshToken(repoHost, cfg, "https")
+		err := oauth2.RefreshToken(repoHost, cfg, "https")
 		if err != nil {
 			return nil, err
 		}
@@ -318,6 +302,9 @@ func NewClientWithCfg(repoHost string, cfg config.Config, isGraphQL bool) (clien
 		isJobToken = true
 	}
 
+	var client *Client
+	var err error
+
 	if caCert != "" && clientCert != "" && keyFile != "" {
 		client, err = NewClientWithCustomCAClientCert(apiHost, authToken, caCert, clientCert, keyFile, isGraphQL, isOAuth2, isJobToken)
 	} else if caCert != "" {
@@ -325,7 +312,14 @@ func NewClientWithCfg(repoHost string, cfg config.Config, isGraphQL bool) (clien
 	} else {
 		client, err = NewClient(apiHost, authToken, skipTlsVerify, isGraphQL, isOAuth2, isJobToken)
 	}
-	return
+	if err != nil {
+		return nil, err
+	}
+	if apiProtocol != "" {
+		client.SetProtocol(apiProtocol)
+	}
+
+	return client, nil
 }
 
 // NewLab initializes the GitLab Client
@@ -348,7 +342,8 @@ func (c *Client) NewLab() error {
 		}
 
 		if c.isOauth2 {
-			c.LabClient, err = gitlab.NewOAuthClient(c.token, gitlab.WithHTTPClient(httpClient), gitlab.WithBaseURL(baseURL))
+			ts := oauthz.StaticTokenSource(&oauthz.Token{AccessToken: c.token})
+			c.LabClient, err = gitlab.NewAuthSourceClient(gitlab.OAuthTokenSource{TokenSource: ts}, gitlab.WithHTTPClient(httpClient), gitlab.WithBaseURL(baseURL))
 		} else if c.isJobToken {
 			c.LabClient, err = gitlab.NewJobClient(c.token, gitlab.WithHTTPClient(httpClient), gitlab.WithBaseURL(baseURL))
 		} else {
