@@ -3,10 +3,6 @@ package api
 import gitlab "gitlab.com/gitlab-org/api/client-go"
 
 var GetCommitStatuses = func(client *gitlab.Client, pid any, sha string) ([]*gitlab.CommitStatus, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
-
 	opt := &gitlab.GetCommitStatusesOptions{
 		All: gitlab.Ptr(true),
 	}
