@@ -14,10 +14,6 @@ const (
 
 // GetFile retrieves a file from repository. Note that file content is Base64 encoded.
 var GetFile = func(client *gitlab.Client, projectID any, path string, ref string) (*gitlab.File, error) {
-	if client == nil {
-		client = apiClient.Lab()
-	}
-
 	fileOpts := &gitlab.GetFileOptions{
 		Ref: &ref,
 	}
