@@ -9,24 +9,24 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
-func NewCmdTrigger(f *cmdutils.Factory) *cobra.Command {
+func NewCmdTrigger(f cmdutils.Factory) *cobra.Command {
 	pipelineTriggerCmd := &cobra.Command{
 		Use:     "trigger <job-id>",
 		Short:   `Trigger a manual CI/CD job.`,
 		Aliases: []string{},
 		Example: heredoc.Doc(`
-		$ glab ci trigger
-		# Interactively select a job to Trigger
+			# Interactively select a job to trigger
+			$ glab ci trigger
 
-		$ glab ci trigger 224356863
-		# Trigger manual job with id 224356863
+			# Trigger manual job with id 224356863
+			$ glab ci trigger 224356863
 
-		$ glab ci trigger lint
-		# Trigger manual job with name lint
-`),
+			# Trigger manual job with name lint
+			$ glab ci trigger lint
+	`),
 		Long: ``,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
@@ -56,11 +56,11 @@ func NewCmdTrigger(f *cmdutils.Factory) *cobra.Command {
 				},
 			}, &ciutils.JobOptions{
 				ApiClient: apiClient,
-				IO:        f.IO,
+				IO:        f.IO(),
 				Repo:      repo,
 			})
 			if err != nil {
-				fmt.Fprintln(f.IO.StdErr, "invalid job ID:", jobName)
+				fmt.Fprintln(f.IO().StdErr, "invalid job ID:", jobName)
 				return err
 			}
 
@@ -72,13 +72,14 @@ func NewCmdTrigger(f *cmdutils.Factory) *cobra.Command {
 			if err != nil {
 				return cmdutils.WrapError(err, fmt.Sprintf("Could not trigger job with ID: %d", jobID))
 			}
-			fmt.Fprintln(f.IO.StdOut, "Triggered job (ID:", job.ID, "), status:", job.Status, ", ref:", job.Ref, ", weburl: ", job.WebURL, ")")
+			output := fmt.Sprintf("Triggered job (ID: %d), status: %s, ref: %s, weburl: %s", job.ID, job.Status, job.Ref, job.WebURL)
+			fmt.Fprintln(f.IO().StdOut, output)
 
 			return nil
 		},
 	}
 
-	pipelineTriggerCmd.Flags().StringP("branch", "b", "", "The branch to search for the job. (Default: current branch)")
+	pipelineTriggerCmd.Flags().StringP("branch", "b", "", "The branch to search for the job. (default current branch)")
 	pipelineTriggerCmd.Flags().IntP("pipeline-id", "p", 0, "The pipeline ID to search for the job.")
 	return pipelineTriggerCmd
 }
