@@ -98,7 +98,7 @@ func ViewJobFromJob(job *gitlab.Job) *ViewJob {
 	return vj
 }
 
-func NewCmdView(f *cmdutils.Factory) *cobra.Command {
+func NewCmdView(f cmdutils.Factory) *cobra.Command {
 	opts := ViewOpts{}
 	pipelineCIView := &cobra.Command{
 		Use:   "view [branch/tag]",
@@ -130,7 +130,7 @@ func NewCmdView(f *cmdutils.Factory) *cobra.Command {
 		`),
 		Args: cobra.MaximumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			opts.Output = f.IO.StdOut
+			opts.Output = f.IO().StdOut
 
 			var err error
 			opts.ApiClient, err = f.HttpClient()
@@ -171,8 +171,8 @@ func NewCmdView(f *cmdutils.Factory) *cobra.Command {
 			if opts.OpenInBrowser { // open in browser if --web flag is specified
 				webURL := opts.Commit.LastPipeline.WebURL
 
-				if f.IO.IsOutputTTY() {
-					fmt.Fprintf(f.IO.StdErr, "Opening %s in your browser.\n", utils.DisplayURL(webURL))
+				if f.IO().IsOutputTTY() {
+					fmt.Fprintf(f.IO().StdErr, "Opening %s in your browser.\n", utils.DisplayURL(webURL))
 				}
 
 				browser, _ := cfg.Get(repo.RepoHost(), "browser")
@@ -184,6 +184,7 @@ func NewCmdView(f *cmdutils.Factory) *cobra.Command {
 				return fmt.Errorf("Can't get pipeline #%d info: %s", opts.Commit.LastPipeline.ID, err)
 			}
 			opts.PipelineUser = p.User
+
 			pipelines = make([]gitlab.PipelineInfo, 0, 10)
 
 			return drawView(opts)
@@ -733,10 +734,14 @@ func updateJobs(
 			pipeline.ProjectID,
 			pipeline.ID,
 		)
-		if (len(jobs) == 0 && len(bridges) == 0) || err != nil {
+		if err != nil {
 			app.Stop()
 			log.Fatal(errors.Wrap(err, "failed to find CI jobs."))
 		}
+		if len(jobs) == 0 && len(bridges) == 0 {
+			app.Stop()
+			log.Fatal("No jobs found in the pipeline. Your '.gitlab-ci.yml' file might be invalid, or the pipeline triggered no jobs.")
+		}
 		viewJobs := make([]*ViewJob, 0, len(jobs)+len(bridges))
 		for _, j := range jobs {
 			viewJobs = append(viewJobs, ViewJobFromJob(j))
