@@ -5,8 +5,8 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
-	"github.com/xanzy/go-gitlab"
-	"gitlab.com/gitlab-org/cli/commands/cmdutils"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
+	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 	"gitlab.com/gitlab-org/cli/test"
@@ -17,12 +17,12 @@ func TestNewCmdCluster(t *testing.T) {
 	r, w, _ := os.Pipe()
 	os.Stdout = w
 
-	assert.Nil(t, NewCmdCluster(&cmdutils.Factory{
-		IO: &iostreams.IOStreams{
+	assert.Nil(t, NewCmdCluster(&cmdtest.Factory{
+		IOStub: &iostreams.IOStreams{
 			StdOut: os.Stdout,
 		},
-		HttpClient: func() (*gitlab.Client, error) { return nil, nil },
-		BaseRepo:   func() (glrepo.Interface, error) { return glrepo.New("OWNER", "REPO"), nil },
+		HttpClientStub: func() (*gitlab.Client, error) { return nil, nil },
+		BaseRepoStub:   func() (glrepo.Interface, error) { return glrepo.New("OWNER", "REPO"), nil },
 	}).Execute())
 
 	out := test.ReturnBuffer(old, r, w)
