@@ -8,6 +8,6 @@ import (
 	issuableNoteCmd "gitlab.com/gitlab-org/cli/commands/issuable/note"
 )
 
-func NewCmdNote(f *cmdutils.Factory) *cobra.Command {
+func NewCmdNote(f cmdutils.Factory) *cobra.Command {
 	return issuableNoteCmd.NewCmdNote(f, issuable.TypeIncident)
 }
