@@ -9,9 +9,9 @@ import (
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/assert"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
-	"gitlab.com/gitlab-org/cli/commands/cmdutils"
+	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 	"gitlab.com/gitlab-org/cli/commands/issuable"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/httpmock"
@@ -77,23 +77,23 @@ func mockAllResponses(t *testing.T, fakeHTTP *httpmock.Mocker) {
 	)
 
 	fakeHTTP.RegisterResponder(http.MethodGet, "/projects/OWNER/REPO/issues/404",
-		httpmock.NewStringResponse(http.StatusNotFound, `{"message": "404 not found"}`),
+		httpmock.NewStringResponse(http.StatusNotFound, `{"message": "404 Not Found"}`),
 	)
 }
 
 func runCommand(rt http.RoundTripper, issuableID string, issueType issuable.IssueType) (*test.CmdOut, error) {
 	ios, _, stdout, stderr := iostreams.Test()
 
-	factory := &cmdutils.Factory{
-		IO: ios,
-		HttpClient: func() (*gitlab.Client, error) {
+	factory := &cmdtest.Factory{
+		IOStub: ios,
+		HttpClientStub: func() (*gitlab.Client, error) {
 			a, err := api.TestClient(&http.Client{Transport: rt}, "", "", false)
 			if err != nil {
 				return nil, err
 			}
 			return a.Lab(), err
 		},
-		BaseRepo: func() (glrepo.Interface, error) {
+		BaseRepoStub: func() (glrepo.Interface, error) {
 			return glrepo.New("OWNER", "REPO"), nil
 		},
 	}
@@ -128,8 +128,8 @@ func TestIssuableClose(t *testing.T) {
 			name:      "issue_close",
 			issueType: issuable.TypeIssue,
 			wantOutput: heredoc.Doc(`
-				- Closing Issue...
-				✓ Closed Issue #1
+				- Closing issue...
+				✓ Closed issue #1
 
 				`),
 		},
@@ -138,8 +138,8 @@ func TestIssuableClose(t *testing.T) {
 			name:      "incident_close",
 			issueType: issuable.TypeIncident,
 			wantOutput: heredoc.Doc(`
-				- Resolving Incident...
-				✓ Resolved Incident #2
+				- Resolving incident...
+				✓ Resolved incident #2
 
 				`),
 		},
@@ -148,8 +148,8 @@ func TestIssuableClose(t *testing.T) {
 			name:      "incident_close_using_issue_command",
 			issueType: issuable.TypeIssue,
 			wantOutput: heredoc.Doc(`
-				- Closing Issue...
-				✓ Closed Issue #2
+				- Closing issue...
+				✓ Closed issue #2
 
 				`),
 		},
@@ -163,7 +163,7 @@ func TestIssuableClose(t *testing.T) {
 			iid:        404,
 			name:       "issue_not_found",
 			issueType:  issuable.TypeIssue,
-			wantOutput: "404 not found",
+			wantOutput: "404 Not Found",
 			wantErr:    true,
 		},
 	}
