@@ -60,9 +60,9 @@ type CreateOpts struct {
 	BaseProject *gitlab.Project `json:"-"`
 }
 
-func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
+func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 	opts := &CreateOpts{
-		IO:      f.IO,
+		IO:      f.IO(),
 		Remotes: f.Remotes,
 		Config:  f.Config,
 	}
