@@ -18,7 +18,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-func NewCmdIssue(f *cmdutils.Factory) *cobra.Command {
+func NewCmdIssue(f cmdutils.Factory) *cobra.Command {
 	issueCmd := &cobra.Command{
 		Use:   "issue [command] [flags]",
 		Short: `Work with GitLab issues.`,
