@@ -8,6 +8,6 @@ import (
 	issuableSubscribeCmd "gitlab.com/gitlab-org/cli/commands/issuable/subscribe"
 )
 
-func NewCmdSubscribe(f *cmdutils.Factory) *cobra.Command {
+func NewCmdSubscribe(f cmdutils.Factory) *cobra.Command {
 	return issuableSubscribeCmd.NewCmdSubscribe(f, issuable.TypeIssue)
 }
