@@ -7,7 +7,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-func NewCmdJob(f *cmdutils.Factory) *cobra.Command {
+func NewCmdJob(f cmdutils.Factory) *cobra.Command {
 	jobCmd := &cobra.Command{
 		Use:   "job <command> [flags]",
 		Short: `Work with GitLab CI/CD jobs.`,
