@@ -60,9 +60,9 @@ type ListOptions struct {
 	HTTPClient func() (*gitlab.Client, error)
 }
 
-func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.Command {
+func NewCmdList(f cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.Command {
 	opts := &ListOptions{
-		IO: f.IO,
+		IO: f.IO(),
 	}
 
 	mrListCmd := &cobra.Command{
