@@ -10,7 +10,6 @@ import (
 
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/require"
-	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/test"
 
 	"github.com/stretchr/testify/assert"
@@ -119,7 +118,7 @@ func TestNewCmdClone(t *testing.T) {
 	for _, tt := range testCases {
 		t.Run(tt.name, func(t *testing.T) {
 			io, stdin, stdout, stderr := iostreams.Test()
-			fac := &cmdutils.Factory{IO: io}
+			fac := &cmdtest.Factory{IOStub: io}
 
 			var opts *CloneOptions
 			var ctxOpts *ContextOpts
