@@ -33,9 +33,9 @@ type Options struct {
 	IO         *iostreams.IOStreams
 }
 
-func NewCmdList(f *cmdutils.Factory) *cobra.Command {
+func NewCmdList(f cmdutils.Factory) *cobra.Command {
 	opts := &Options{
-		IO: f.IO,
+		IO: f.IO(),
 	}
 	repoListCmd := &cobra.Command{
 		Use:   "list",
