@@ -30,9 +30,9 @@ type ViewOptions struct {
 	Repo glrepo.Interface
 }
 
-func NewCmdView(f *cmdutils.Factory) *cobra.Command {
+func NewCmdView(f cmdutils.Factory) *cobra.Command {
 	opts := ViewOptions{
-		IO: f.IO,
+		IO: f.IO(),
 	}
 
 	projectViewCmd := &cobra.Command{
