@@ -17,9 +17,9 @@ type RunOpts struct {
 	IO         *iostreams.IOStreams
 }
 
-func NewCmdRun(f *cmdutils.Factory) *cobra.Command {
+func NewCmdRun(f cmdutils.Factory) *cobra.Command {
 	opts := &RunOpts{
-		IO: f.IO,
+		IO: f.IO(),
 	}
 	scheduleRunCmd := &cobra.Command{
 		Use:   "run <id>",
