@@ -25,9 +25,9 @@ type DeleteOpts struct {
 	Group string
 }
 
-func NewCmdDelete(f *cmdutils.Factory, runE func(opts *DeleteOpts) error) *cobra.Command {
+func NewCmdDelete(f cmdutils.Factory, runE func(opts *DeleteOpts) error) *cobra.Command {
 	opts := &DeleteOpts{
-		IO: f.IO,
+		IO: f.IO(),
 	}
 
 	cmd := &cobra.Command{
