@@ -28,9 +28,9 @@ type ListOpts struct {
 	OutputFormat string
 }
 
-func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOpts) error) *cobra.Command {
+func NewCmdList(f cmdutils.Factory, runE func(opts *ListOpts) error) *cobra.Command {
 	opts := &ListOpts{
-		IO: f.IO,
+		IO: f.IO(),
 	}
 
 	cmd := &cobra.Command{
